@@ -13,7 +13,7 @@ copy_file "#{__dir__}/config/babel.config.js", "babel.config.js"
 say "Copying .browserslistrc to app root directory"
 copy_file "#{__dir__}/config/.browserslistrc", ".browserslistrc"
 
-if Dir.exists?(Webpacker.config.source_path)
+if Dir.exist?(Webpacker.config.source_path)
   say "The JavaScript app source directory already exists"
 else
   say "Creating JavaScript app source directory"
@@ -22,7 +22,7 @@ end
 
 apply "#{__dir__}/binstubs.rb"
 
-if File.exists?(".gitignore")
+if File.exist?(".gitignore")
   append_to_file ".gitignore" do
     "\n"                   +
     "/public/packs\n"      +
