@@ -1,5 +1,3 @@
-const { join } = require('path')
-const { cache_path: cachePath } = require('../config')
 const { nodeEnv } = require('../env')
 
 // Compile standard ES features for JS in node_modules with Babel.
@@ -14,7 +12,7 @@ module.exports = {
       options: {
         babelrc: false,
         presets: [['@babel/preset-env', { modules: false }]],
-        cacheDirectory: join(cachePath, 'babel-loader-node-modules'),
+        cacheDirectory: true,
         cacheCompression: nodeEnv === 'production',
         compact: false,
         sourceMaps: false
